**To delete a monitor**

The following ``delete-monitor`` example deletes a monitor named ``Example_NetworkMonitor``. ::

    aws networkmonitor delete-monitor \
        --monitor-name Example_NetworkMonitor

This command produces no output.

For more information, see `How Amazon CloudWatch Network Monitor Works <https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/nw-monitor-how-it-works.html>`__ in the *Amazon CloudWatch User Guide*.